<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       example.com
 * @since      1.0.0
 *
 * @package    Learndash_Flashcards
 * @subpackage Learndash_Flashcards/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Learndash_Flashcards
 * @subpackage Learndash_Flashcards/admin
 * @author     Srikanth <srikanthkoneru631@gmail.com>
 */
class Learndash_Flashcards_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Learndash_Flashcards_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Learndash_Flashcards_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/learndash-flashcards-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Learndash_Flashcards_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Learndash_Flashcards_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_media();
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/learndash-flashcards-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Create coupon post type
	 *
	 * To add a class to body tag of plugin admin page
	 *
	 * @since    1.0.0
	 * @access   public
	 */
	public function create_flashcard_post_type() {

		$labels = array(
			'name'                  => esc_html_x( 'Flashcards', 'Post type general name', 'learndash-flashcards' ),
			'singular_name'         => esc_html_x( 'Flashcard', 'Post type singular name', 'learndash-flashcards' ),
			'menu_name'             => esc_html_x( 'Flashcards', 'Admin Menu text', 'learndash-flashcards' ),
			'name_admin_bar'        => esc_html_x( 'Flashcard', 'Add New on Toolbar', 'learndash-flashcards' ),
			'add_new'               => esc_html__( 'Add New Flashcard', 'learndash-flashcards' ),
			'add_new_item'          => esc_html__( 'Add New Flashcard', 'learndash-flashcards' ),
			'new_item'              => esc_html__( 'New Flashcard', 'learndash-flashcards' ),
			'edit_item'             => esc_html__( 'Edit Flashcard', 'learndash-flashcards' ),
			'view_item'             => esc_html__( 'View Flashcard', 'learndash-flashcards' ),
			'all_items'             => esc_html__( 'All Flashcards', 'learndash-flashcards' ),
			'search_items'          => esc_html__( 'Search Flashcards', 'learndash-flashcards' ),
			'parent_item_colon'     => esc_html__( 'Parent Coupon:', 'learndash-flashcards' ),
			'not_found'             => esc_html__( 'No Flashcards found.', 'learndash-flashcards' ),
			'not_found_in_trash'    => esc_html__( 'No Flashcards found in Trash.', 'learndash-flashcards' ),
			'featured_image'        => esc_html_x( 'Coupon Image', 'Overrides the “Featured Image” phrase for this post type. Added in 4.3', 'learndash-flashcards' ),
			'set_featured_image'    => esc_html_x( 'Set Coupon image', 'Overrides the “Set featured image” phrase for this post type. Added in 4.3', 'learndash-flashcards' ),
			'remove_featured_image' => esc_html_x( 'Remove Coupon image', 'Overrides the “Remove featured image” phrase for this post type. Added in 4.3', 'learndash-flashcards' ),
			'use_featured_image'    => esc_html_x( 'Use as Coupon image', 'Overrides the “Use as featured image” phrase for this post type. Added in 4.3', 'learndash-flashcards' ),
			'archives'              => esc_html_x( 'Coupon archives', 'The post type archive label used in nav menus. Default “Post Archives”. Added in 4.4', 'learndash-flashcards' ),
			'insert_into_item'      => esc_html_x( 'Insert into Flashcard', 'Overrides the “Insert into post”/”Insert into page” phrase (used when inserting media into a post). Added in 4.4', 'learndash-flashcards' ),
			'uploaded_to_this_item' => esc_html_x( 'Uploaded to this Flashcard', 'Overrides the “Uploaded to this post”/”Uploaded to this page” phrase (used when viewing media attached to a post). Added in 4.4', 'learndash-flashcards' ),
			'filter_items_list'     => esc_html_x( 'Filter Flashcards', 'Screen reader text for the filter links heading on the post type listing screen. Default “Filter posts list”/”Filter pages list”. Added in 4.4', 'learndash-flashcards' ),
			'items_list_navigation' => esc_html_x( 'Wishlist navigation', 'Screen reader text for the pagination heading on the post type listing screen. Default “Posts list navigation”/”Flashcards navigation”. Added in 4.4', 'learndash-flashcards' ),
			'items_list'            => esc_html_x( 'Flashcards', 'Screen reader text for the items list heading on the post type listing screen. Default “Posts list”/”Pages list”. Added in 4.4', 'learndash-flashcards' ),
		);

		$args = array(
			'labels'             => $labels,
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => false,
			'query_var'          => true,
			'rewrite'            => array( 'slug' => 'learndash-flashcards' ),
			'capability_type'    => 'post',
			'has_archive'        => true,
			'hierarchical'       => true,
			'menu_position'      => null,
			'supports'           => array( 'title', 'taxonomies' ),
			'show_in_rest'       => true,
		);

		register_post_type( 'ld-flashcards', $args );

	}

	public function create_flashcards_taxonomy() {

		$location_labels = array(
			'name'              => esc_html_x( 'Flashcards Set', 'taxonomy general name', 'learndash-flashcards' ),
			'singular_name'     => esc_html_x( 'Set', 'taxonomy singular name', 'learndash-flashcards' ),
			'search_items'      => esc_html__( 'Search Sets', 'learndash-flashcards' ),
			'all_items'         => esc_html__( 'All Sets', 'learndash-flashcards' ),
			'parent_item'       => esc_html__( 'Parent Set', 'learndash-flashcards' ),
			'parent_item_colon' => esc_html__( 'Parent Set :', 'learndash-flashcards' ),
			'edit_item'         => esc_html__( 'Edit Set', 'learndash-flashcards' ),
			'update_item'       => esc_html__( 'Update Set', 'learndash-flashcards' ),
			'add_new_item'      => esc_html__( 'Add New Set', 'learndash-flashcards' ),
			'new_item_name'     => esc_html__( 'New Set', 'learndash-flashcards' ),
			'menu_name'         => esc_html__( 'Set', 'learndash-flashcards' ),
		);

		$location_args = array(
			'hierarchical'      => true,
			'labels'            => $location_labels,
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'ld-fc-set' ),
		);

		register_taxonomy( 'ld-fc-set', array( 'ld-flashcards' ), $location_args );

	}

	public function add_coupon_admin_menu( $add_submenu ) {

		$add_submenu['ld-flashcards'] = array(
			'name'  => esc_html_x( 'Flashcards', 'Flashcards for marketing', 'learndash-flashcards' ),
			'cap'   => 'administrator',
			'link'  => 'edit.php?post_type=ld-flashcards',
			'class' => 'submenu-ldlms-essays',
		);

		return $add_submenu;

	}

	public function learndash_flashcards_add_meta_box() {

		add_meta_box( 'learndash_flashcards_meta_box', __( 'Flashcard Settings', 'learndash-flashcards' ), array( $this, 'learndash_flashcards_add_meta_box_html' ), 'ld-flashcards', 'normal', '', null );

	}

	public function learndash_flashcards_add_meta_box_html( $object ) {

		wp_nonce_field( basename( __FILE__ ), 'learndash-flashcards-meta-nonce' );

		$front_title = get_post_meta( $object->ID, 'learndash-flashcards-front-title', true );
		if ( ! $front_title ) {
			$front_title = '';
		}

		$front_content = get_post_meta( $object->ID, 'learndash-flashcards-front-content', true );
		if ( ! $front_content ) {
			$front_content = '';
		}

		$front_bg     = get_post_meta( $object->ID, 'learndash-flashcards-front-bg', true );
		$front_bg_url = '';
		if ( ! $front_bg ) {
			$front_bg = '';
		} else {
			$front_bg_url = wp_get_attachment_url( $front_bg );
		}

		$front_bg_color = get_post_meta( $object->ID, 'learndash-flashcards-front-bg-color', true );
		if ( ! $front_bg_color ) {
			$front_bg_color = '';
		}

		$front_text_color = get_post_meta( $object->ID, 'learndash-flashcards-front-text-color', true );
		if ( ! $front_text_color ) {
			$front_text_color = '';
		}

		$back_title = get_post_meta( $object->ID, 'learndash-flashcards-back-title', true );
		if ( ! $back_title ) {
			$back_title = '';
		}

		$back_content = get_post_meta( $object->ID, 'learndash-flashcards-back-content', true );
		if ( ! $back_content ) {
			$back_content = '';
		}

		$back_bg_color = get_post_meta( $object->ID, 'learndash-flashcards-back-bg-color', true );
		if ( ! $back_bg_color ) {
			$back_bg_color = '';
		}

		$back_bg = get_post_meta( $object->ID, 'learndash-flashcards-back-bg', true );
		if ( ! $back_bg ) {
			$back_bg     = '';
			$back_bg_url = '';
		} else {
			$back_bg_url = wp_get_attachment_url( $back_bg );
		}

		$back_text_color = get_post_meta( $object->ID, 'learndash-flashcards-back-text-color', true );
		if ( ! $back_text_color ) {
			$back_text_color = '';
		}

		echo '<p>';
		echo '<label for="learndash-flashcards-front-title">' . __( 'Front Title', 'learndash-flashcards' ) . '</label><br />';
		echo '<input id="learndash-flashcards-front-title" type="text" name="learndash-flashcards-front-title"  value="' . esc_attr( $front_title ) . '" />';
		echo '</p>';

		echo '<p>';
		echo '<label for="learndash-flashcards-front-content">' . __( 'Front Content', 'learndash-flashcards' ) . '</label><br />';
		echo '<input id="learndash-flashcards-front-content" type="text" name="learndash-flashcards-front-content"  value="' . esc_attr( $front_content ) . '" />';
		echo '</p>';

		echo '<p>';
		echo '<label for="learndash-flashcards-front-text-color">' . __( 'Front Text Color', 'learndash-flashcards' ) . '</label><br />';
		echo '<input id="learndash-flashcards-front-text-color" type="text" name="learndash-flashcards-front-text-color"  value="' . esc_attr( $front_text_color ) . '" />';
		echo '</p>';

		echo '<p>';
		echo '<label for="learndash-flashcards-front-bg-color">' . __( 'Front Background Color', 'learndash-flashcards' ) . '</label><br />';
		echo '<input id="learndash-flashcards-front-bg-color" type="text" name="learndash-flashcards-front-bg-color"  value="' . esc_attr( $front_bg_color ) . '" />';
		echo '</p>';

		echo '<div class="learndash-flashcards-bg-input">';
		echo '<label for="learndash-flashcards-front-bg">' . __( 'Front Bg', 'learndash-flashcards' ) . '</label><br />';
		echo '<input id="learndash-flashcards-front-bg" type="hidden" name="learndash-flashcards-front-bg"  value="' . esc_attr( $front_bg ) . '" />';
		echo '<div class="learndash-flashcards-image-setting">';
		echo '<div class="learndash-flashcards-no-image" ' . ( ( $front_bg_url ) ? 'style="display:none;"' : '' ) . '>';
		echo '<p class="learndash-flashcards-image-empty"><span>' . esc_html__( 'Add Image', 'learndash-flashcards' ) . '</span></p>';
		echo '</div>';
		echo '<div class="learndash-flashcards-image" ' . ( ( $front_bg_url ) ? 'style="display:block;"' : '' ) . '>';
		echo '<img src="' . $front_bg_url . '" />';
		echo '</div>';
		echo '<span class="learndash-flashcards-image-close" ' . ( ( $front_bg_url ) ? 'style="display:block;"' : '' ) . '>';
		echo '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" focusable="false" width="2em" height="2em" style="-ms-transform: rotate(360deg); -webkit-transform: rotate(360deg); transform: rotate(360deg);" preserveAspectRatio="xMidYMid meet" viewBox="0 0 1024 1024"><path d="M880 112H144c-17.7 0-32 14.3-32 32v736c0 17.7 14.3 32 32 32h736c17.7 0 32-14.3 32-32V144c0-17.7-14.3-32-32-32zM676.1 657.9c4.4 5.2.7 13.1-6.1 13.1h-58.9c-4.7 0-9.2-2.1-12.3-5.7L512 561.8l-86.8 103.5c-3 3.6-7.5 5.7-12.3 5.7H354c-6.8 0-10.5-7.9-6.1-13.1L470.2 512L347.9 366.1A7.95 7.95 0 0 1 354 353h58.9c4.7 0 9.2 2.1 12.3 5.7L512 462.2l86.8-103.5c3-3.6 7.5-5.7 12.3-5.7H670c6.8 0 10.5 7.9 6.1 13.1L553.8 512l122.3 145.9z" fill="#f56969"/></svg>';
		echo '</span>';
		echo '</div>';
		echo '</div>';

		echo '<p>';
		echo '<label for="learndash-flashcards-back-title">' . __( 'Back Title', 'learndash-flashcards' ) . '</label><br />';
		echo '<input id="learndash-flashcards-back-title" type="text" name="learndash-flashcards-back-title"  value="' . esc_attr( $back_title ) . '" />';
		echo '</p>';

		echo '<p>';
		echo '<label for="learndash-flashcards-back-content">' . __( 'Back Content', 'learndash-flashcards' ) . '</label><br />';
		echo '<input id="learndash-flashcards-back-content" type="text" name="learndash-flashcards-back-content"  value="' . esc_attr( $back_content ) . '" />';
		echo '</p>';

		echo '<p>';
		echo '<label for="learndash-flashcards-back-text-color">' . __( 'Back Text Color', 'learndash-flashcards' ) . '</label><br />';
		echo '<input id="learndash-flashcards-back-text-color" type="text" name="learndash-flashcards-back-text-color"  value="' . esc_attr( $back_text_color ) . '" />';
		echo '</p>';

		echo '<p>';
		echo '<label for="learndash-flashcards-back-bg-color">' . __( 'Back Background Color', 'learndash-flashcards' ) . '</label><br />';
		echo '<input id="learndash-flashcards-back-bg-color" type="text" name="learndash-flashcards-back-bg-color"  value="' . esc_attr( $back_bg_color ) . '" />';
		echo '</p>';

		echo '<div class="learndash-flashcards-bg-input">';
		echo '<label for="learndash-flashcards-back-bg">' . __( 'Back Bg', 'learndash-flashcards' ) . '</label><br />';
		echo '<input id="learndash-flashcards-back-bg" type="hidden" name="learndash-flashcards-back-bg"  value="' . esc_attr( $back_bg ) . '" />';
		echo '<div class="learndash-flashcards-image-setting">';
		echo '<div class="learndash-flashcards-no-image" ' . ( ( $back_bg_url ) ? 'style="display:none;"' : '' ) . '>';
		echo '<p class="learndash-flashcards-image-empty"><span>' . esc_html__( 'Add Image', 'learndash-flashcards' ) . '</span></p>';
		echo '</div>';
		echo '<div class="learndash-flashcards-image" ' . ( ( $back_bg_url ) ? 'style="display:block;"' : '' ) . '>';
		echo '<img src="' . $back_bg_url . '" />';
		echo '</div>';
		echo '<span class="learndash-flashcards-image-close" ' . ( ( $back_bg_url ) ? 'style="display:block;"' : '' ) . '>';
		echo '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" aria-hidden="true" focusable="false" width="2em" height="2em" style="-ms-transform: rotate(360deg); -webkit-transform: rotate(360deg); transform: rotate(360deg);" preserveAspectRatio="xMidYMid meet" viewBox="0 0 1024 1024"><path d="M880 112H144c-17.7 0-32 14.3-32 32v736c0 17.7 14.3 32 32 32h736c17.7 0 32-14.3 32-32V144c0-17.7-14.3-32-32-32zM676.1 657.9c4.4 5.2.7 13.1-6.1 13.1h-58.9c-4.7 0-9.2-2.1-12.3-5.7L512 561.8l-86.8 103.5c-3 3.6-7.5 5.7-12.3 5.7H354c-6.8 0-10.5-7.9-6.1-13.1L470.2 512L347.9 366.1A7.95 7.95 0 0 1 354 353h58.9c4.7 0 9.2 2.1 12.3 5.7L512 462.2l86.8-103.5c3-3.6 7.5-5.7 12.3-5.7H670c6.8 0 10.5 7.9 6.1 13.1L553.8 512l122.3 145.9z" fill="#f56969"/></svg>';
		echo '</span>';
		echo '</div>';
		echo '</div>';

	}

	public function learndash_flashcards_save_meta( $post_id ) {

		if ( ! isset( $_POST['learndash-flashcards-meta-nonce'] ) || ! wp_verify_nonce( $_POST['learndash-flashcards-meta-nonce'], basename( __FILE__ ) ) ) {
			return $post_id;
		}

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return $post_id;
		}

		if ( isset( $_POST['post_type'] ) && 'ld-flashcards' === $_POST['post_type'] ) {

			if ( isset( $_POST['learndash-flashcards-front-title'] ) ) {

				$update_flashcards_front_title = update_post_meta( $post_id, 'learndash-flashcards-front-title', sanitize_text_field( $_POST['learndash-flashcards-front-title'] ) );

				if ( false === $update_flashcards_front_title ) {

					add_action(
						'admin_notices',
						function() {

							?>
						<div class="error">
							<p><?php esc_html_e( 'Failed to add/update front title', 'learndash-flashcards' ); ?></p>
						</div>
							<?php

						}
					);

				}
			}

			if ( isset( $_POST['learndash-flashcards-front-content'] ) ) {

				$update_flashcards_front_content = update_post_meta( $post_id, 'learndash-flashcards-front-content', sanitize_text_field( $_POST['learndash-flashcards-front-content'] ) );

				if ( false === $update_flashcards_front_content ) {

					add_action(
						'admin_notices',
						function() {

							?>
						<div class="error">
							<p><?php esc_html_e( 'Failed to add/update front content', 'learndash-flashcards' ); ?></p>
						</div>
							<?php

						}
					);

				}
			}

			if ( isset( $_POST['learndash-flashcards-front-text-color'] ) ) {

				$update_flashcards_front_text_color = update_post_meta( $post_id, 'learndash-flashcards-front-text-color', sanitize_text_field( $_POST['learndash-flashcards-front-text-color'] ) );

				if ( false === $update_flashcards_front_text_color ) {

					add_action(
						'admin_notices',
						function() {

							?>
						<div class="error">
							<p><?php esc_html_e( 'Failed to add/update front text color', 'learndash-flashcards' ); ?></p>
						</div>
							<?php

						}
					);

				}
			}

			if ( isset( $_POST['learndash-flashcards-front-bg-color'] ) ) {

				$update_flashcards_front_bg_color = update_post_meta( $post_id, 'learndash-flashcards-front-bg-color', sanitize_text_field( $_POST['learndash-flashcards-front-bg-color'] ) );

				if ( false === $update_flashcards_front_bg_color ) {

					add_action(
						'admin_notices',
						function() {

							?>
						<div class="error">
							<p><?php esc_html_e( 'Failed to add/update front bg color', 'learndash-flashcards' ); ?></p>
						</div>
							<?php

						}
					);

				}
			}

			if ( isset( $_POST['learndash-flashcards-front-bg'] ) ) {

				$update_flashcards_front_bg = update_post_meta( $post_id, 'learndash-flashcards-front-bg', sanitize_text_field( $_POST['learndash-flashcards-front-bg'] ) );

				if ( false === $update_flashcards_front_bg ) {

					add_action(
						'admin_notices',
						function() {

							?>
						<div class="error">
							<p><?php esc_html_e( 'Failed to add/update front bg', 'learndash-flashcards' ); ?></p>
						</div>
							<?php

						}
					);

				}
			}

			if ( isset( $_POST['learndash-flashcards-back-title'] ) ) {

				$update_flashcards_back_title = update_post_meta( $post_id, 'learndash-flashcards-back-title', sanitize_text_field( $_POST['learndash-flashcards-back-title'] ) );

				if ( false === $update_flashcards_back_title ) {

					add_action(
						'admin_notices',
						function() {

							?>
						<div class="error">
							<p><?php esc_html_e( 'Failed to add/update back title', 'learndash-flashcards' ); ?></p>
						</div>
							<?php

						}
					);

				}
			}

			if ( isset( $_POST['learndash-flashcards-back-content'] ) ) {

				$update_flashcards_back_content = update_post_meta( $post_id, 'learndash-flashcards-back-content', sanitize_text_field( $_POST['learndash-flashcards-back-content'] ) );

				if ( false === $update_flashcards_back_content ) {

					add_action(
						'admin_notices',
						function() {

							?>
						<div class="error">
							<p><?php esc_html_e( 'Failed to add/update back content', 'learndash-flashcards' ); ?></p>
						</div>
							<?php

						}
					);

				}
			}

			if ( isset( $_POST['learndash-flashcards-back-text-color'] ) ) {

				$update_flashcards_back_text_color = update_post_meta( $post_id, 'learndash-flashcards-back-text-color', sanitize_text_field( $_POST['learndash-flashcards-back-text-color'] ) );

				if ( false === $update_flashcards_back_text_color ) {

					add_action(
						'admin_notices',
						function() {

							?>
						<div class="error">
							<p><?php esc_html_e( 'Failed to add/update back text color', 'learndash-flashcards' ); ?></p>
						</div>
							<?php

						}
					);

				}
			}

			if ( isset( $_POST['learndash-flashcards-back-bg-color'] ) ) {

				$update_flashcards_front_bg_color = update_post_meta( $post_id, 'learndash-flashcards-back-bg-color', sanitize_text_field( $_POST['learndash-flashcards-back-bg-color'] ) );

				if ( false === $update_flashcards_front_bg_color ) {

					add_action(
						'admin_notices',
						function() {

							?>
						<div class="error">
							<p><?php esc_html_e( 'Failed to add/update back bg color', 'learndash-flashcards' ); ?></p>
						</div>
							<?php

						}
					);

				}
			}

			if ( isset( $_POST['learndash-flashcards-back-bg'] ) ) {

				$update_flashcards_back_bg = update_post_meta( $post_id, 'learndash-flashcards-back-bg', sanitize_text_field( $_POST['learndash-flashcards-back-bg'] ) );

				if ( false === $update_flashcards_back_bg ) {

					add_action(
						'admin_notices',
						function() {

							?>
						<div class="error">
							<p><?php esc_html_e( 'Failed to add/update back bg', 'learndash-flashcards' ); ?></p>
						</div>
							<?php

						}
					);

				}
			}
		}

	}



}
