<?php

require_once( plugin_dir_path( __FILE__ ) . 'updater.php' );

if ( ! function_exists( 'get_current_plugin_slug' ) ) {
	function get_current_plugin_slug( $file ) {
		$plugin_root_files = array_filter(
			scandir( plugin_dir_path( $file ) . '../' ),
			function ( $file_name ) {
				if ( in_array( $file_name, [ 'index.php', 'uninstall.php' ] ) ) {
					return false;
				}

				if ( substr( $file_name, -4, 4 ) !== '.php' ) {
					return false;
				}

				return true;
			}
		);

		$plugin_file_name = end( $plugin_root_files );

		$immerseus_plugin_data = get_plugin_data( plugin_dir_path( $file ) . '../' . $plugin_file_name );

		$immerseus_plugin_name = $immerseus_plugin_data['Name'];

		return strtolower( str_replace( ' ', '-', $immerseus_plugin_name ) ) . '-upgrader';
	}
}

add_action( 'admin_menu', function () {
	global $immerseus_upgrader_data;

	$plugin_root_files = array_filter(
		scandir( plugin_dir_path( __FILE__ ) . '../' ),
		function ( $file_name ) {
			if ( in_array( $file_name, [ 'index.php', 'uninstall.php' ] ) ) {
				return false;
			}

			if ( substr( $file_name, -4, 4 ) !== '.php' ) {
				return false;
			}

			return true;
		}
	);

	$plugin_file_name = end( $plugin_root_files );

	$immerseus_plugin_data = get_plugin_data( plugin_dir_path( __FILE__ ) . '../' . $plugin_file_name );

	$immerseus_plugin_name = $immerseus_plugin_data['Name'];
	$immerseus_plugin_slug = strtolower( str_replace( ' ', '-', $immerseus_plugin_name ) ) . '-upgrader';

	$immerseus_upgrader_data[ $immerseus_plugin_slug ] = [
		'plugin_name'        => $immerseus_plugin_name,
		'plugin_menu_slug'   => '',
		'sub_menu_slug'      => $immerseus_plugin_slug,
		'license_menu_label' => $immerseus_plugin_name,
		'license_page_title' => $immerseus_plugin_name . ' ' . __( 'License Verification', 'immerseus' ),
		'check_url'          => 'http://immerseus.com/wp-json/immerseus-license/v1/check',
		'site_url'           => get_site_url( null, '', 'http' ),
		'basename'           => plugin_basename( __FILE__ ),
		'plugin_version'     => $immerseus_plugin_data['Version'],
	];
}, 10, 0 );

add_action( 'admin_init', function () {
	global $immerseus_upgrader_data;

	$immerseus_plugin_slug = get_current_plugin_slug( __FILE__ );

	if ( is_array( $immerseus_upgrader_data ) && array_key_exists( $immerseus_plugin_slug, $immerseus_upgrader_data ) ) {
		$license = get_option( 'immerseus-' . $immerseus_plugin_slug . '-license-id', '' );

		if ( ! empty( $license ) ) {
			$license = json_decode( $license, true );

			if ( is_array( $license ) ) {
				if (
					array_key_exists( 'code', $license ) &&
					! empty( $license['code'] ) &&
					array_key_exists( 'email', $license ) &&
					! empty( $license['email'] )
				) {
					$license_code_value  = esc_html( $license['code'] );
					$license_email_value = esc_html( $license['email'] );
					// set auto-update params
					$plugin_current_version = $immerseus_upgrader_data[ $immerseus_plugin_slug ]['plugin_version'];
					$plugin_remote_path     = $immerseus_upgrader_data[ $immerseus_plugin_slug ]['check_url'];
					$plugin_slug            = $immerseus_upgrader_data[ $immerseus_plugin_slug ]['basename'];
					$license_key            = $license_code_value;
					$site_url               = $immerseus_upgrader_data[ $immerseus_plugin_slug ]['site_url'];
					$plugin_name            = $immerseus_upgrader_data[ $immerseus_plugin_slug ]['plugin_name'];
					$plugin_key             = $immerseus_plugin_slug;

					// only perform Auto-Update call if a license_user and license_key is given
					if ( $license_key && $plugin_remote_path ) {
						$update = new WP_AutoUpdate ( $plugin_current_version, $plugin_remote_path, $plugin_slug, $license_key, $site_url, $plugin_name, $plugin_key, $license_email_value );

						add_filter( 'site_transient_update_plugins', [ $update, 'check_update' ], 10, 1 );
						add_filter( 'plugins_api', [ $update, 'check_info' ], 10, 3 );
					}
				}
			}
		}
	}
}, 11, 0 );

add_action( 'admin_menu', function () {
	global $immerseus_upgrader_data;

	$immerseus_plugin_slug = get_current_plugin_slug( __FILE__ );

	if ( empty( $immerseus_upgrader_data[ $immerseus_plugin_slug ]['plugin_menu_slug'] ) ) {
		if ( empty( $GLOBALS['admin_page_hooks']['immerseusupgrader'] ) ) {
			add_menu_page(
				__( 'Immerseus', 'immerseus' ),
				__( 'Immerseus', 'immerseus' ),
				'manage_options',
				'immerseusupgrader',
				function () {
					return '';
				},
				null,
				20
			);
		}
		$immerseus_upgrader_data[ $immerseus_plugin_slug ]['plugin_menu_slug'] = 'immerseusupgrader';
	}

	add_submenu_page(
		$immerseus_upgrader_data[ $immerseus_plugin_slug ]['plugin_menu_slug'],
		$immerseus_upgrader_data[ $immerseus_plugin_slug ]['license_menu_label'],
		$immerseus_upgrader_data[ $immerseus_plugin_slug ]['license_menu_label'],
		'manage_options',
		$immerseus_plugin_slug,
		function () use ( $immerseus_plugin_slug ) {
			global $immerseus_upgrader_data;

			$message       = '';
			$message_class = 'immerseus-admin-error';

			$license            = get_option( 'immerseus-' . $immerseus_plugin_slug . '-license-id', '' );
			$license_code_value = '';
			$license_code_email = '';

			if ( ! empty( $license ) ) {
				$license = json_decode( $license, true );

				if ( is_array( $license ) ) {
					if (
						array_key_exists( 'code', $license ) &&
						! empty( $license['code'] )
					) {
						$license_code_value = $license['code'];
					}

					if (
						array_key_exists( 'email', $license ) &&
						! empty( $license['email'] )
					) {
						$license_code_email = $license['email'];
					}

					if ( ! empty( $license['code'] ) && ! empty( $license_code_email ) ) {
						$update_option_value = [
							'code'   => esc_html( $license_code_value ),
							'email'  => esc_html( $license_code_email ),
							'site'   => esc_url_raw( $immerseus_upgrader_data[ $immerseus_plugin_slug ]['site_url'] ),
							'plugin' => esc_html( $immerseus_upgrader_data[ $immerseus_plugin_slug ]['plugin_name'] ),
						];

						$license_check = wp_remote_post(
							$immerseus_upgrader_data[ $immerseus_plugin_slug ]['check_url'],
							[
								'method'      => 'POST',
								'timeout'     => 45,
								'redirection' => 5,
								'httpversion' => '1.0',
								'blocking'    => true,
								'headers'     => [],
								'body'        => $update_option_value,
								'cookies'     => [],
							]
						);
						if ( is_wp_error( $license_check ) ) {
							$message = esc_html__( 'Something went wrong, Please try again 1', 'immerseus' );
						} else {
							$license_check_result = json_decode( $license_check['body'], true );
							if (
								is_array( $license_check_result ) &&
								array_key_exists( 'result', $license_check_result ) &&
								false !== $license_check_result['result'] &&
								array_key_exists( 'data', $license_check_result ) &&
								array_key_exists( 'license', $license_check_result['data'] ) &&
								true === $license_check_result['data']['license']
							) {
								$message       = esc_html__( 'Auto upgrades are enabled.', 'immerseus' );
								$message_class = 'immerseus-admin-success';
							} else {
								$update_option_value = [
									'code'   => '',
									'email'  => '',
									'site'   => esc_url_raw( $immerseus_upgrader_data[ $immerseus_plugin_slug ]['site_url'] ),
									'plugin' => sanitize_text_field( $immerseus_upgrader_data[ $immerseus_plugin_slug ]['plugin_name'] ),
								];
								$update_option_value = wp_json_encode( $update_option_value );

								update_option( 'immerseus-' . $immerseus_plugin_slug . '-license-id', $update_option_value, false );

								$license_code_value = '';
								$license_code_email = '';
							}
						}
					}
				}
			}

			if ( isset( $_POST['immerseus-license-update'] ) ) {
				$message = '';

				if (
				wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['immerseus_license_update_nonce'] ) ), 'immerseus_license_update' )
				) {
					if ( ! isset( $_POST['immerseus-license-code'] ) || empty( $_POST['immerseus-license-code'] ) ) {
						$message            .= '<p>' . esc_html__( 'Please enter your license code.', 'immerseus' ) . '</p>';
						$message_class      = 'immerseus-admin-error';
						$license_code_value = '';
					} elseif ( isset( $_POST['immerseus-license-code'] ) && ! empty( $_POST['immerseus-license-code'] ) ) {
						$license_code_value = sanitize_text_field( wp_unslash( $_POST['immerseus-license-code'] ) );
					}

					if ( ! isset( $_POST['immerseus-license-email'] ) || empty( $_POST['immerseus-license-email'] ) ) {
						$message            .= '<p>' . esc_html__( 'Please enter your email.', 'immerseus' ) . '</p>';
						$message_class      = 'immerseus-admin-error';
						$license_code_email = '';
					} elseif ( isset( $_POST['immerseus-license-email'] ) && ! empty( $_POST['immerseus-license-email'] ) ) {
						$license_code_email = sanitize_email( wp_unslash( $_POST['immerseus-license-email'] ) );
					}

					if ( empty( $license_code_value ) || empty( $license_code_email ) ) {
						$update_option_value = [
							'code'   => $license_code_value,
							'email'  => $license_code_email,
							'site'   => $immerseus_upgrader_data[ $immerseus_plugin_slug ]['site_url'],
							'plugin' => $immerseus_upgrader_data[ $immerseus_plugin_slug ]['plugin_name'],
						];

						$update_option_value = wp_json_encode( $update_option_value );

						update_option( 'immerseus-' . $immerseus_plugin_slug . '-license-id', $update_option_value, false );
					}

					if ( ! empty( $license_code_value ) && ! empty( $license_code_email ) && ! empty( $immerseus_upgrader_data[ $immerseus_plugin_slug ]['check_url'] ) ) {
						$update_option_value = [
							'code'   => $license_code_value,
							'email'  => $license_code_email,
							'site'   => $immerseus_upgrader_data[ $immerseus_plugin_slug ]['site_url'],
							'plugin' => $immerseus_upgrader_data[ $immerseus_plugin_slug ]['plugin_name'],
							'action' => 'write',
						];

						$license_check = wp_remote_post(
							$immerseus_upgrader_data[ $immerseus_plugin_slug ]['check_url'],
							[
								'method'      => 'POST',
								'timeout'     => 45,
								'redirection' => 5,
								'httpversion' => '1.0',
								'blocking'    => true,
								'headers'     => [],
								'body'        => $update_option_value,
								'cookies'     => [],
							]
						);

						if ( is_wp_error( $license_check ) ) {
							$message = esc_html__( 'Something went wrong, Please try again 3', 'immerseus' );
						} else {
							$license_check_result = json_decode( $license_check['body'], true );

							if (
								is_array( $license_check_result ) &&
								array_key_exists( 'result', $license_check_result ) &&
								false !== $license_check_result['result']
							) {
								if (
									array_key_exists( 'data', $license_check_result ) &&
									array_key_exists( 'license', $license_check_result['data'] ) &&
									false !== $license_check_result['data']['license']
								) {
									$update_option_value = wp_json_encode( $update_option_value );

									update_option( 'immerseus-' . $immerseus_plugin_slug . '-license-id', $update_option_value, false );

									$message       = esc_html__( 'Auto upgrades are enabled now.', 'immerseus' );
									$message_class = 'immerseus-admin-success';
								} else {
									if (
									! array_key_exists( 'data', $license_check_result )
									) {
										$message       = esc_html__( 'Something went wrong, Please try again 4', 'immerseus' );
										$message_class = 'immerseus-admin-error';
									} elseif (
										array_key_exists( 'data', $license_check_result ) &&
										! array_key_exists( 'license', $license_check_result['data'] )
									) {
										$message       = esc_html__( 'Something went wrong, Please try again 5', 'immerseus' );
										$message_class = 'immerseus-admin-error';
									} elseif (
										array_key_exists( 'data', $license_check_result ) &&
										array_key_exists( 'license', $license_check_result['data'] ) &&
										false === $license_check_result['data']['license']
									) {
										if ( array_key_exists( 'reason', $license_check_result['data'] ) ) {
											$message = esc_html( $license_check_result['data']['reason'] );
										} else {
											$message = esc_html__( 'Something went wrong, Please try again 6', 'immerseus' );
										}

										$message_class = 'immerseus-admin-error';
									}
								}
							} else {
								$message = esc_html__( 'Something went wrong, Please try again 7', 'immerseus' );
								$message_class = 'immerseus-admin-error';
							}
						}
					}
				} else {
					$message = esc_html__( 'Something went wrong, Please try again 2', 'immerseus' );
					$message_class = 'immerseus-admin-error';
				}
			}

			echo '<div class="wrap">';

			echo '<h1>' . $immerseus_upgrader_data[ $immerseus_plugin_slug ]['license_page_title'] . '</h1>';

			echo '<div class="immerseus-admin-container">';

			echo '<form action="" method="post">';
			wp_nonce_field( 'immerseus_license_update', 'immerseus_license_update_nonce' );

			if ( $message ) {
				echo '<div class="' . esc_attr( $message_class ) . '">' . $message . '</div>';
			}

			echo '<div><input type="text" name="immerseus-license-code" placeholder="' . esc_attr__( 'Your License Code', 'immerseus' ) . '" value="' . esc_attr( $license_code_value ) . '" /></div>';
			echo '<div><input type="text" name="immerseus-license-email" placeholder="' . esc_attr__( 'Your Email', 'immerseus' ) . '" value="' . esc_attr( $license_code_email ) . '" /></div>';
			echo '<div class="immerseus-admin-submit"><input name="immerseus-license-update" type="submit" value="' . esc_attr__( 'Submit', 'immerseus' ) . '" /></div>';
			echo '</form>';

			echo '</div>';

			echo '</div>';
		}
	);
}, 11, 0 );

add_action( 'admin_menu', function () {
	remove_submenu_page( 'immerseusupgrader', 'immerseusupgrader' );
}, 12, 0 );

add_action( 'admin_enqueue_scripts', function () {
	$immerseus_plugin_slug = get_current_plugin_slug( __FILE__ );

	wp_enqueue_style( $immerseus_plugin_slug, plugin_dir_url( __DIR__ ) . 'immerseus-upgrader/css/immerseus.css', [], '1.0.0', 'all' );
}, 10, 0 );

