<?php

if ( ! class_exists( 'WP_AutoUpdate' ) ) {
	class WP_AutoUpdate {
		/**
		 * The plugin current version
		 * @var string
		 */
		private $current_version;

		/**
		 * The plugin remote update path
		 * @var string
		 */
		private $update_path;

		/**
		 * Plugin Slug (plugin_directory/plugin_file.php)
		 * @var string
		 */
		private $plugin_slug;

		/**
		 * Plugin Name
		 * @var string
		 */
		private $plugin_name;

		/**
		 * Plugin key
		 * @var string
		 */
		private $plugin_key;

		/**
		 * Plugin name (plugin_file)
		 * @var string
		 */
		private $slug;

		/**
		 * License User
		 * @var string
		 */
		private $site_url;

		/**
		 * License Key
		 * @var string
		 */
		private $license_key;

		/**
		 * License Email
		 * @var string
		 */
		private $license_email;

		/**
		 * Initialize a new instance of the WordPress Auto-Update class
		 *
		 * @param string $current_version
		 * @param string $update_path
		 * @param string $plugin_slug
		 */
		public function __construct( $current_version, $update_path, $plugin_slug, $license_key, $site_url, $plugin_name, $plugin_key, $license_email ) {
			[ $t1, $t2 ] = explode( '/', $plugin_slug );

			// Set the class public variables
			$this->current_version = $current_version;
			$this->update_path     = $update_path;

			// Set the License
			$this->site_url = $site_url;

			$this->license_key = $license_key;

			// Set the Plugin Slug
			$this->plugin_slug = $plugin_slug;

			$this->slug = str_replace( '.php', '', $t2 );

			$this->plugin_name = $plugin_name;

			$this->plugin_key = $plugin_key;

			$this->license_email = $license_email;

			// define the alternative API for updating checking

			// Define the alternative response for information checking
			//add_filter( 'plugins_api', array( &$this, 'check_info' ), 10, 3 );
		}

		/**
		 * Add our self-hosted autoupdate plugin to the filter transient
		 *
		 * @param $transient
		 *
		 * @return object $ transient
		 */
		public function check_update( $transient ) {
			if ( empty( $transient->checked ) ) {
				return $transient;
			}

			// Get the remote version
			$remote_version = $this->getRemote();

			//check if license is valid
			if ( $remote_version['data']['license'] ) {
				// If a newer version is available, add the update
				if ( version_compare( $this->current_version, $remote_version['data']['details']['version'], '<' ) ) {
					$obj                                       = new stdClass();
					$obj->slug                                 = $this->slug;
					$obj->new_version                          = sanitize_text_field( $remote_version['data']['details']['version'] );
					$obj->url                                  = '';
					$obj->plugin                               = $this->plugin_slug;
					$obj->package                              = sanitize_text_field( $remote_version['data']['details']['url'] );
					$obj->tested                               = '';
					$transient->response[ $this->plugin_slug ] = $obj;
				}
			} else {
				//Remove license key and show admin notice
				update_option( 'immerseus-' . $this->plugin_key . '-license-id', '' );
			}

			return $transient;
		}

		/**
		 * Add our self-hosted description to the filter
		 *
		 * @param boolean $false
		 * @param array $action
		 * @param object $arg
		 *
		 * @return bool|object
		 */
		public function check_info( $obj, $action, $arg ) {
			if ( ( $action == 'query_plugins' || $action == 'plugin_information' ) &&
			     isset( $arg->slug ) && $arg->slug === $this->slug ) {
				$remote_version = $this->getRemote();
				if ( is_array( $remote_version ) ) {
					// If a newer version is available, add the update
					$obj              = new stdClass();
					$obj->name        = $this->plugin_name;
					$obj->slug        = $this->slug;
					$obj->new_version = sanitize_text_field( $remote_version['data']['details']['version'] );
					$obj->url         = '';
					$obj->plugin      = $this->plugin_slug;
					$obj->package     = '';
					$obj->tested      = '';
					$obj->sections    = [
						'description' => sanitize_text_field( $remote_version['data']['details']['info'] ),
					];

					return $obj;
				}
			}

			return $obj;
		}

		/**
		 * Return the remote version
		 *
		 * @return string $remote_version
		 */
		public function getRemote() {
			$immerseus_remote_data = get_transient( $this->slug . '-updater-remote' );

			if ( false === $immerseus_remote_data ) {
				$params = [
					'body'    => [
						'site'   => $this->site_url,
						'code'   => $this->license_key,
						'plugin' => $this->plugin_name,
						'email'  => $this->license_email,
					],
					'timeout' => 45,
				];

				// Make the POST request
				$request = wp_remote_post( $this->update_path, $params );

				// Check if response is valid
				if ( ! is_wp_error( $request ) || wp_remote_retrieve_response_code( $request ) === 200 ) {
					$immerseus_remote_data = json_decode( $request['body'], true );
					set_transient( $this->slug . '-updater-remote', $immerseus_remote_data, rand( 12, 24 ) * HOUR_IN_SECONDS );

					return $immerseus_remote_data;
				}
			} else {
				return $immerseus_remote_data;
			}

			return false;
		}
	}
}
