<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://honorswp.com
 * @since             1.0.0
 * @package           Learndash_Flashcards
 *
 * @wordpress-plugin
 * Plugin Name:       Flashcards for LearnDash
 * Plugin URI:        https://honorswp.com
 * Description:       Create and display flashcards to help learners learn visually and retain knowledge.
 * Version:           1.1.0
 * Author:            HonorsWP
 * Author URI:        https://honorswp.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       learndash-flashcards
 * Domain Path:       /languages
 */

// namespace EA_FLASHCARDS_LD;

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

require_once __DIR__ . '/vendor/autoload.php';

use EA\Licensing\License;

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'LEARNDASH_FLASHCARDS_VERSION', '1.1.0' );
define( 'LEARNDASH_FLASHCARDS_PATH', plugin_dir_path( __FILE__ ) );
define( 'LEARNDASH_FLASHCARDS_URL', plugins_url( '', __FILE__ ) );

/**
 * Licensing.
 */
new License(
	__( 'Flashcards for LearnDash', 'learndash-flashcards' ),
	6626,
	'flashcards-for-learndash',
	__FILE__,
	LEARNDASH_FLASHCARDS_VERSION
);

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-learndash-flashcards-activator.php
 */
function activate_learndash_flashcards() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-learndash-flashcards-activator.php';
	Learndash_Flashcards_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-learndash-flashcards-deactivator.php
 */
function deactivate_learndash_flashcards() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-learndash-flashcards-deactivator.php';
	Learndash_Flashcards_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_learndash_flashcards' );
register_deactivation_hook( __FILE__, 'deactivate_learndash_flashcards' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-learndash-flashcards.php';

/**
 * Traits for our classes,
 * Responsible for rendering blocks, widgets and shortcodes.
 */
require plugin_dir_path( __FILE__ ) . 'admin/traits.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_learndash_flashcards() {

	$plugin = new Learndash_Flashcards();
	$plugin->run();

}
run_learndash_flashcards();

// require_once plugin_dir_path( __FILE__ ) . 'immerseus-upgrader/index.php';
